@@ -30,19 +30,25 @@ class BrowserV2:
             active_sleep: bool = False,
             profile_path: str = None,
             rotative_agent: bool = False,
-            version_main: str = None
+            version_main: str = None,
+            use_profile: bool = False
     ) -> None:
 
         self.__version_main = version_main
         self.__active_sleep = active_sleep
         self.__rotative_agent = rotative_agent
+        self.__use_profile = use_profile
         BrowserV2.__options = uc.ChromeOptions()
 
-        if profile_path is not None:
-            if not os.path.exists(profile_path):
-                os.makedirs(profile_path)
-            # BrowserV2.__options.add_argument("--profile-directory=Default")
-            BrowserV2.__options.add_argument('--user-data-dir=' + profile_path)
+        if (profile_path is not None) and (use_profile is False):
+            raise Exception('To use profile_path, enable the use_profile option. (Eg. use_profile = True)')
+
+        if use_profile:
+            if profile_path is not None:
+                if not os.path.exists(profile_path):
+                    os.makedirs(profile_path)
+                # BrowserV2.__options.add_argument("--profile-directory=Default")
+                BrowserV2.__options.add_argument('--user-data-dir=' + profile_path)
 
         BrowserV2.user_agents = list(Utils.get_agent_users())
 
